@@ -1534,7 +1534,9 @@ sub mkorigtargz {
     my $mk_origtargz_out;
     my $path   = "$self->{config}->{destdir}/$self->{newfile_base}";
     my $target = $self->newfile_base;
-    unless ($self->symlink eq "no" or $self->symlink eq "0") {
+    my $skip_mk_origtargz
+      = ($self->symlink eq "no" or $self->symlink eq "0") ? 1 : 0;
+    unless ($skip_mk_origtargz) {
         require Devscripts::MkOrigtargz;
         if ($Devscripts::MkOrigtargz::found_comp) {
             uscan_verbose
@@ -1676,7 +1678,10 @@ sub mkorigtargz {
             }
             push @cmd, "--upstream-version",
               $self->shared->{common_mangled_newversion};
-            if (abs_path($self->{config}->{destdir}) ne abs_path("..")) {
+            if (!$skip_mk_origtargz
+                and abs_path($self->{config}->{destdir}) ne abs_path("..")) {
+                # mk_origtargz expects tarballs in ".." but they aren't there
+                # if destdir is set
                 foreach my $origtar (@{ $self->shared->{origtars} }) {
                     copy(catfile($self->{config}->{destdir}, $origtar),
                         catfile("..", $origtar));
