@@ -224,8 +224,7 @@ if ($cdata->get_option('is_pgp_signed')) {
 }
 
 my @architectures = split /\s+/, $cdata->{"Architecture"};
-my $build_source  = (scalar(grep /^source$/, @architectures)) == 1;
-my $build_archall = (scalar(grep /^all$/,    @architectures)) == 1;
+my $build_archall = (scalar(grep /^all$/, @architectures)) == 1;
 @architectures = grep { !/^source$/ && !/^all$/ } @architectures;
 if (scalar @architectures > 1) {
     die "more than one architecture in Architecture field\n";
@@ -635,6 +634,14 @@ if ($builder eq "none") {
     print $fh "\$apt_get = '/bin/true';\n";
     print $fh "\$apt_cache = '/bin/true';\n";
     print $fh "\$build_as_root_when_needed = 1;\n";
+# pass snapshot date to Debian installer so it can receive the right packages itself
+# can be dropped once #806984 is fixed
+    if ($srcpkgname eq "debian-installer") {
+        my $build_date = Time::Piece->strptime($cdata->{"Build-Date"},
+            '%a, %d %b %Y %T %z');
+        print $fh "\$build_environment = {'SNAPSHOT_TS' => '"
+          . $build_date->strftime('%Y%m%dT%H%M%SZ') . "'};\n";
+    }
     close $fh;
     my @cmd = (
         'env', "--chdir=$outdir", @environment, "SBUILD_CONFIG=$sbuildrc",
@@ -643,11 +650,6 @@ if ($builder eq "none") {
     push @cmd, "--build=$build_arch";
     push @cmd, "--host=$host_arch";
 
-    if ($build_source) {
-        push @cmd, '--source';
-    } else {
-        push @cmd, '--no-source';
-    }
     if ($build_archany) {
         push @cmd, '--arch-any';
     } else {
@@ -670,6 +672,9 @@ if ($builder eq "none") {
     push @cmd, "--no-apt-update";
     push @cmd, "--no-apt-upgrade";
     push @cmd, "--no-apt-distupgrade";
+# Do not build a .dsc as we can't reproduce it.
+# Also see comment at the end of this script when comparing the buildinfo files.
+    push @cmd, "--no-source";
     # Buildinfo files do not indicate whether fakeroot was installed,
     # so it is not included in the recreated chroot.
     # Since most packages build without issues,
@@ -698,6 +703,14 @@ if ($builder eq "none") {
         push @cmd, "--build-path=$build_path";
         push @cmd, "--dsc-dir=$dirs[-1]";
     }
+# Can be dropped once fixed in the packages: #806984 #807168
+# also done on the buildd see:
+# https://salsa.debian.org/dsa-team/mirror/dsa-puppet/-/blob/production/modules/buildd/files/sbuild-wrapper
+    if (   $srcpkgname eq "debian-installer"
+        || $srcpkgname eq "debian-installer-netboot-images") {
+        push @cmd, "--enable-network";
+    }
+
     push @cmd, (File::Spec->rel2abs($dsc_fname));
     print((join " ", @cmd) . "\n");
     0 == system @cmd or die "sbuild failed\n";
