@@ -308,8 +308,6 @@ if [ -n "$DEBSIGN_PROGRAM" ]; then
 else
     if command -v gpg > /dev/null; then
 	signcommand=gpg
-    elif command -v gpg2 > /dev/null; then
-	signcommand=gpg2
     fi
 fi
 
