@@ -244,7 +244,7 @@ sub get_file {
     $seen{$file} = 1;
 
     if ($file =~ /\.(?:changes|dsc)$/) {
-        parse_file($dir, $file);
+        parse_file($dir, $file) or return 0;
     }
     if ($file =~ /\.dsc$/) {
         $found_dsc = $file;
@@ -263,10 +263,11 @@ sub parse_file {
             my ($_sum, $_file) = ($1, $2);
             $_file !~ m,[/\x00],
               or die "File name contains invalid characters: $_file";
-            get_file($dir, $_file, $_sum) or return;
+            get_file($dir, $_file, $_sum) or return 0;
         }
     }
     close $fh;
+    return 1;
 }
 
 sub quote_version {
