@@ -391,6 +391,63 @@ Examples:
 Rename branch given in B<--source-branch> with name given in B<--dest-branch>.
 You can use B<--no-fail>, B<--all> and B<--all-archived> options here.
 
+=item B<rename_branches>
+
+Rename several branches at once in a given project.
+The first argument is the project name, followed by branch mappings.
+The default branch is detected automatically and updated if renamed.
+
+  salsa rename_branches my-project master:debian/latest debian/master:debian/unstable
+
+You can use B<--no-wait> to avoid waiting for the changes to be reflected on the server,
+and B<--no-fail> to continue even if a branch rename fails.
+
+  salsa rename_branches --no-wait --no-fail my-project master:debian/latest
+
+You can use B<--dep14> to use DEP-14 default branch mappings.
+
+  salsa rename_branches --dep14 my-project
+
+=item B<file>
+
+Manipulate repository files on Salsa.
+
+  salsa file <get|create|edit|delete|create_or_edit> <project_name> <file_path> [options]
+
+=over
+
+=item B<get>
+
+Retrieves the content of a file from a repository.
+
+  salsa file get my-project README.md --ref my-branch
+
+=item B<create>
+
+Creates a new file in a repository.
+
+  salsa file create my-project README.md --content-from-file path/to/README.md --branch my-branch --commit-message "Add README"
+
+=item B<edit>
+
+Edits an existing file in a repository.
+
+  salsa file edit my-project README.md --content-from-file path/to/README.md --branch my-branch --commit-message "Update README"
+
+=item B<delete>
+
+Deletes a file from a repository.
+
+  salsa file delete my-project README.md --branch my-branch --commit-message "Remove README"
+
+=item B<create_or_edit>
+
+Creates a new file or edits an existing file in a repository.
+
+  salsa file create_or_edit my-project README.md --content-from-file path/to/README.md --branch my-branch --commit-message "Update README"
+
+=back
+
 =item B<search_projects> or B<search_repo> or B<search>
 
 Search for a project using given string. Shows name, owner ID and other
@@ -431,6 +488,13 @@ Update C<debian/watch> file for each given project to L<version 5|debian-watch(5
 
 Options B<--all> and B<--debian-branch> are usable here.
 
+=item B<update_gbp_conf>
+
+Update debian/gbp.conf with the branches discovered on the server.
+The first argument is the project name.
+
+  salsa update_gbp_conf my-project
+
 =item B<path>
 
 Little subcommand to get salsa path from a local git repo:
@@ -924,6 +988,12 @@ when set to yes.
 
 C<.devscripts> value: B<SALSA_NO_FAIL> (yes/no, default: no)
 
+=item B<--no-wait>
+
+Don't wait for the server to confirm the changes.
+
+C<.devscripts> value: B<SALSA_NO_WAIT> (yes/no, default: no)
+
 =item B<--rename-head>, B<--no-rename-head>
 
 Rename HEAD branch given by B<--source-branch> into B<--dest-branch> and change
@@ -958,6 +1028,28 @@ C<.devscripts> value: B<SALSA_TAGPENDING> (yes/ignore/no, default: ignore)
 Set the branch to update for B<update_watch5> command. Default to project's
 default branch.
 
+=item B<--dep14>
+
+Use DEP-14 default branch mappings for C<rename_branches> command.
+
+C<.devscripts> value: B<SALSA_DEP14> (yes/no)
+
+=item B<--branch>
+
+Branch to use for C<file> command.
+
+=item B<--ref>
+
+Ref to use for C<file get> command.
+
+=item B<--commit-message>
+
+Commit message to use for C<file> command.
+
+=item B<--content-from-file>
+
+File to read content from, for the C<file> command.
+
 =back
 
 =head2 Pipeline schedules
